@@ -34,6 +34,9 @@ class SDK:
         self.viewer = None
         self.set_viewer(viewer)
 
+    def set_public_url(self, public_url: str):
+        self.api.set_public_url(public_url)
+
     def set_viewer(self, viewer: str):
         """
         Allows to choose one of available viewers
@@ -394,7 +397,8 @@ class SDK:
         annotation_set_id: int,
         annotation_format: str = 'json',
         export_coordinates: str = 'pixel',
-        full_path: str = 'true',
+        full_path: bool = True,
+        export_tags : bool = True
     ) -> bytes:
         """
         Exports annotations in given format
@@ -402,9 +406,9 @@ class SDK:
         Args:
             annotation_set_id: annotation set id
             annotation_format: can be one of ['json', 'coco', 'csv'], default='json'
-            full_path: uses full image path (e.g. local path), can be one of ['true', 'false'], default='false'
+            full_path: uses full image path (e.g. local path),  it can be one of [True, False], default=True
             export_coordinates: converts output values to percentage or pixels, can be one of ['pixel', 'percent'], default='pixel'
-
+            export_tags: exports the tags to a CSV file, it can be one of [True, False], default=True
         Returns:
             annotation file content
         """
@@ -413,6 +417,7 @@ class SDK:
             annotation_format=annotation_format,
             export_coordinates=export_coordinates,
             full_path=full_path,
+            export_tags=export_tags
         )
 
     def export_annotations_to_file(
@@ -421,7 +426,8 @@ class SDK:
         annotation_set_id: int,
         annotation_format: str = 'json',
         export_coordinates: str = 'pixel',
-        full_path: str = 'true',
+        full_path: bool = True,
+        export_tags: bool = True
     ):
         """
         Exports annotations in given format
@@ -430,14 +436,16 @@ class SDK:
             output_file: output file to save
             annotation_set_id: annotation set id
             annotation_format: can be one of ['json', 'coco', 'csv'], default='json'
-            full_path: uses full image path (e.g. local path), can be one of ['true', 'false'], default='false'
+            full_path: uses full image path (e.g. local path),  it can be one of [True, False], default=True
             export_coordinates: converts output values to percentage or pixels, can be one of ['pixel', 'percent'], default='pixel'
+            export_tags: exports the tags to a CSV file, it can be one of [True, False], default=True
         """
         content = self.export_annotations(
             annotation_set_id,
             annotation_format=annotation_format,
             export_coordinates=export_coordinates,
             full_path=full_path,
+            export_tags=export_tags
         )
         self._save_to_file(content, output_file)
 
@@ -775,7 +783,7 @@ class SDK:
         return self._view(frontend.annotation_set_insights.format(annotation_set_id))
 
     def _view(self, url, *args, **kwargs):
-        return self.viewer.browse(self.api.url(url, *args, **kwargs))
+        return self.viewer.browse(self.api.public_url(url, *args, **kwargs))
     
     def generate_annotations_from_folders(self, path_to_data_folder: str):
         """
